# what it's called on pypi
%global pypi_name curio
# what it's imported as
%global libname curio
# name of egg info directory
%global eggname curio
# package name fragment
%global pkgname curio

%global _description \
Curio is a library of building blocks for performing concurrent I/O and common\
system programming tasks such as launching subprocesses, working with files,\
and farming work out to thread and process pools.  It uses Python coroutines\
and the explicit async/await syntax introduced in Python 3.5.  Its programming\
model is based on cooperative multitasking and existing programming\
abstractions such as threads, sockets, files, subprocesses, locks, and queues.\
You'll find it to be small, fast, and fun.  Curio has no third-party\
dependencies and does not use the standard asyncio module.  Most users will\
probably find it to be a bit too-low level--it's probably best to think of it\
as a library for building libraries.  Although you might not use it directly,\
many of its ideas have influenced other libraries with similar functionality.

%bcond_without tests


Name:       python-%{pkgname}
Version:    1.6
Release:    %mkrel 5
Summary:    Building blocks for performing concurrent I/O
License:    BSD
Group:      Development/Python
URL:        https://pypi.org/project/curio
Source0:    %pypi_source
# fix for Python 3.12 https://github.com/dabeaz/curio/pull/363
Patch0:     363.patch
# fix telnetlib removed from python 3.13
Patch1:     curio-remove-old-dependencies.patch
BuildArch:  noarch


%description %{_description}


%package -n python3-%{pkgname}
Summary:        %{summary}
Group:      Development/Python
BuildRequires:  python3-devel
%if %{with tests}
BuildRequires:  python3-pytest
%endif
%{?python_provide:%python_provide python3-%{pkgname}}


%description -n python3-%{pkgname} %{_description}


%prep
%autosetup -n %{pypi_name}-%{version} -p 1


%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files curio


%if %{with tests}
%check
PYTHONPATH=%{buildroot}%{python3_sitelib} py.test-%{python3_version} --verbose -m 'not internet'
%endif

%files -n python3-%{pkgname} -f %{pyproject_files}
%license LICENSE
%doc README.rst


%changelog
* Fri Mar 07 2025 papoteur <papoteur> 1.6-5.mga10
+ Revision: 2161818
- patch for python3.13 compatibility, removing telnetlib requirement
- rebuild for python 3.13
+ wally <wally>
- rebuild for python3.13
- rebuild for python3.13

* Mon Dec 11 2023 papoteur <papoteur> 1.6-2.mga10
+ Revision: 2017188
- fix for python 3.12 from upstream
- rebuild for python3.12
- adapt to pyproject

* Tue Nov 15 2022 guillomovitch <guillomovitch> 1.6-1.mga9
+ Revision: 1907674
- new version 1.6

* Sat Mar 26 2022 umeabot <umeabot> 1.5-3.mga9
+ Revision: 1828440
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 wally <wally> 1.5-2.mga9
+ Revision: 1773499
- rebuild for python3.10

* Tue Mar 23 2021 guillomovitch <guillomovitch> 1.5-1.mga9
+ Revision: 1708525
- new version 1.5

* Sun Jan 17 2021 guillomovitch <guillomovitch> 1.4-1.mga8
+ Revision: 1672132
- imported package python-curio

